@@ -120,40 +120,12 @@ predictors = [
           'КОД_ОШИБКИ',  # 2
           'КОД_ЦЛК',  # 7
           'СТОППИР',
-
           'H_СЛЯБ', 'B_СЛЯБ', 'L_СЛЯБ', 'ВЕС_СЛ', 'ВЕСФ_СЛ', 'H_ЛИСТ', 'B_ЛИСТ', 'L_ЛИСТ',  # 3
           'КРАТ', 'ПЕЧЬ_РЯД', 'ДЛИТ_ПЕЧЬ', 'ПЛ_Т_ПЕЧЬ', 'ФК_Т_ПЕЧЬ', 'СХЕМА_ПРОК', 'ДУО_ПРОХ',  # 1
           'ДУО_ХОЛОСТ', 'ГИДРОСБИВ',  # 3
-          'Group_ДУО_ОБЖ_01', 'Group_ДУО_ОБЖ_02','Group_ДУО_ОБЖ_03','Group_ДУО_ОБЖ_04','Group_ДУО_ОБЖ_05',
-          'Group_ДУО_ОБЖ_06','Group_ДУО_ОБЖ_07','Group_ДУО_ОБЖ_08','Group_ДУО_ОБЖ_09','Group_ДУО_ОБЖ_10',
-          'Group_ДУО_ОБЖ_11','Group_ДУО_ОБЖ_12','Group_ДУО_ОБЖ_13','Group_ДУО_ОБЖ_14','Group_ДУО_ОБЖ_15',  # 8
-          'Group_ДУО_УСС_01', 'Group_ДУО_УСС_02', 'Group_ДУО_УСС_03', 'Group_ДУО_УСС_04', 'Group_ДУО_УСС_05',
-          'Group_ДУО_УСС_06', 'Group_ДУО_УСС_07', 'Group_ДУО_УСС_08', 'Group_ДУО_УСС_09', 'Group_ДУО_УСС_10',
-          'Group_ДУО_УСС_11', 'Group_ДУО_УСС_12', 'Group_ДУО_УСС_13', 'Group_ДУО_УСС_14', 'Group_ДУО_УСС_15',
-          'Group_ДУО_УСП_01', 'Group_ДУО_УСП_02', 'Group_ДУО_УСП_03', 'Group_ДУО_УСП_04', 'Group_ДУО_УСП_05',
-          'Group_ДУО_УСП_06', 'Group_ДУО_УСП_07', 'Group_ДУО_УСП_08', 'Group_ДУО_УСП_09', 'Group_ДУО_УСП_10',
-          'Group_ДУО_УСП_11', 'Group_ДУО_УСП_12', 'Group_ДУО_УСП_13', 'Group_ДУО_УСП_14', 'Group_ДУО_УСП_15',
-          'Group_ДУО_СКР_01', 'Group_ДУО_СКР_02', 'Group_ДУО_СКР_03', 'Group_ДУО_СКР_04', 'Group_ДУО_СКР_05',
-          'Group_ДУО_СКР_06', 'Group_ДУО_СКР_07', 'Group_ДУО_СКР_08', 'Group_ДУО_СКР_09', 'Group_ДУО_СКР_10',
-          'Group_ДУО_СКР_11', 'Group_ДУО_СКР_12', 'Group_ДУО_СКР_13', 'Group_ДУО_СКР_14', 'Group_ДУО_СКР_15',
           'ДУО_Т_3_ПР',  # 7
           'ДУО_Т_ПОСЛ',  # 6
           'ПОДКАТ',  # 6
-          'Group_КВР_ОБЖ_01', 'Group_КВР_ОБЖ_02', 'Group_КВР_ОБЖ_03', 'Group_КВР_ОБЖ_04', 'Group_КВР_ОБЖ_05',
-          'Group_КВР_ОБЖ_06', 'Group_КВР_ОБЖ_07', 'Group_КВР_ОБЖ_08', 'Group_КВР_ОБЖ_09', 'Group_КВР_ОБЖ_10',
-          'Group_КВР_ОБЖ_11', 'Group_КВР_ОБЖ_12', 'Group_КВР_ОБЖ_13', 'Group_КВР_ОБЖ_14', 'Group_КВР_ОБЖ_15',
-          'Group_КВР_УСС_01', 'Group_КВР_УСС_02', 'Group_КВР_УСС_03', 'Group_КВР_УСС_04', 'Group_КВР_УСС_05',
-          'Group_КВР_УСС_06', 'Group_КВР_УСС_07', 'Group_КВР_УСС_08', 'Group_КВР_УСС_09', 'Group_КВР_УСС_10',
-          'Group_КВР_УСС_11', 'Group_КВР_УСС_12', 'Group_КВР_УСС_13', 'Group_КВР_УСС_14', 'Group_КВР_УСС_15',
-          'Group_КВР_УСП_01', 'Group_КВР_УСП_02', 'Group_КВР_УСП_03', 'Group_КВР_УСП_04', 'Group_КВР_УСП_05',
-          'Group_КВР_УСП_06', 'Group_КВР_УСП_07', 'Group_КВР_УСП_08', 'Group_КВР_УСП_09', 'Group_КВР_УСП_10',
-          'Group_КВР_УСП_11', 'Group_КВР_УСП_12', 'Group_КВР_УСП_13', 'Group_КВР_УСП_14', 'Group_КВР_УСП_15',
-          'Group_КВР_СКР_01', 'Group_КВР_СКР_02', 'Group_КВР_СКР_03', 'Group_КВР_СКР_04', 'Group_КВР_СКР_05',
-          'Group_КВР_СКР_06', 'Group_КВР_СКР_07', 'Group_КВР_СКР_08', 'Group_КВР_СКР_09', 'Group_КВР_СКР_10',
-          'Group_КВР_СКР_11', 'Group_КВР_СКР_12', 'Group_КВР_СКР_13', 'Group_КВР_СКР_14', 'Group_КВР_СКР_15',
-          'Group_DELTA1_2', 'Group_DELTA2_3', 'Group_DELTA3_4', 'Group_DELTA4_5', 'Group_DELTA5_6', 'Group_DELTA6_7',
-          'Group_DELTA7_8', 'Group_DELTA8_9', 'Group_DELTA9_10', 'Group_DELTA10_11', 'Group_DELTA11_12', 'Group_DELTA12_13',
-          'Group_DELTA13_14', 'Group_DELTA14_15',
           'КВР_Т_ПЛАН',  # 2
           'КВР_Т_1_ПР',  # 7
           'S2_START',  # 3
