@@ -12,17 +12,16 @@ from sklearn.model_selection import train_test_split
 
 import time
 
-from .columns import targets, time_columns, label_encoders, error_codes, groups, exclude, predictors, group_starts_with
-from .preprocessing import time2num, encode, process_error_codes, load_columns, load_targets
-from .important_features import get_important_features
-
+from .columns import exclude
 sns.set()
 
 
 class MechModel:
     def __init__(self, targets, features, pca):
         self.targets = targets
+        self.targets.sort()
         self.features = features
+        self.features.sort()
         self.pca = pca
 
         self.performance = {key: {} for key in self.targets}
@@ -51,6 +50,7 @@ class MechModel:
                 features_temp = self._list_replace(features_temp, column,
                                                    f'Group_{columns_with_prefix[0]}')
             features_temp = list(set(features_temp))
+            features_temp.sort()
         return features_temp
 
     def to_features(self, data, target=''):
@@ -69,6 +69,7 @@ class MechModel:
 
         # features_temp = list(set(features_temp)-set(exclude[target]))
         features_temp = list(set(features_temp)-set_exclude)
+        features_temp.sort()
 
         # return data.drop(exclude[target], axis=1, errors='ignore')
         return data[features_temp]
@@ -245,7 +246,9 @@ class MechModel:
         # print(data.shape)
 
         Y = ()
-        X = data[self._colapse_features_list()].values
+        X = data[self._colapse_features_list()]
+        print('X.columns: ', X.columns)
+        X = X.values
 
         if X.shape[0]==1:
             sl = np.isnan(X)
