@@ -154,6 +154,7 @@ class Data_Preprocessor:
         print(data)
 
         if self.mode == 'predict':
+            data.fillna(np.nan, inplace=True)
             return data
 
         elif self.mode == 'train':
@@ -175,12 +176,15 @@ class Data_Preprocessor:
                     print(target, '             ', important_columns)
                     temp.update(important_columns)
 
+                # print('     ', temp)
                 temp = [
-                        col if col in groups
+                        col if col in predictors
                         else group_starts_with[col]
                         for col in list(temp)
                 ]
+                # print("----->", temp)
                 self.features = list(flatten(temp))
+                # print(self.features)
 
                 # leave in self.pca only important pca transformers
                 important_pca_keys = get_pca_key_for_features(temp)
