@@ -223,12 +223,37 @@ class DB_Connector:
 
         return df
 
-    def get_reliability(self, model_id: int, data_id: int) -> bool:
-        query = self._create_where_query(model_id)
-        query += ' and ID=%s'
-
+    def get_data(self, data_id: int) -> pd.DataFrame:
+        query = 'select * from Data_Model where id=%s'
         self.cursor.execute(query, (data_id))
         data = self.cursor.fetchall()
-        df = pd.DataFrame(data)
+        return pd.DataFrame(data)
 
-        return bool(df.shape[0])
+    def get_reliability_and_data(self,
+                                 model_id: int,
+                                 data_id: int
+                                 ) -> tuple[bool, pd.DataFrame]:
+
+        query = self._create_where_query(model_id) + ' and ID=%s'
+        self.cursor.execute(query, (data_id))
+        data = self.cursor.fetchall()
+        is_reliable = bool(pd.DataFrame(data).shape[0])
+
+        data = self.get_data(data_id)
+
+        return is_reliable, data
+
+
+if __name__=='__main__':
+    USERNAME = ''
+    PASSWORD = ''
+    HOST = ''
+    DB = ''
+
+    model_id = 51
+    data_id = 5
+
+    dbm = DB_Connector(HOST, USERNAME, PASSWORD, DB)
+    is_reliable, data = dbm.get_reliability_and_data(model_id, data_id)
+
+    print(data, '\n', is_reliable)
